@@ -1,5 +1,7 @@
+import time
 from K10CR1.k10cr1 import K10CR1
 
+WAIT_TIME = 1
 name = "K10CR1"
 hwid = ["0403:FAF0"]
 
@@ -19,9 +21,12 @@ class instrument:
 
     def home(self):
         self.rotator.home()
+        time.sleep(WAIT_TIME)
 
     def move_abs(self, value):
         self.rotator.moveabs(value)
+        time.sleep(WAIT_TIME)
 
     def move_rel(self, val_dif):
         self.rotator.moverel(val_dif)
+        time.sleep(WAIT_TIME)
